__all__ = [
    'update_device_switch_port',
    'update_network',
    'update_network_alert_settings',
    'default_destinations',
    'alert',
    'update_network_appliance_port',
    'bind_network',
    'update_network_bluetooth_settings',
    'generate_network_camera_snapshot',
    'update_network_cellular_firewall_rules',
    'rule',
    'provision_network_clients',
    'update_network_client_policy',
    'update_network_client_splash_authorization_status',
    'ssids',
    'update_network_connectivity_monitoring_destinations',
    'destination',
    'update_network_content_filtering',
    'claim_network_devices',
    'update_network_device',
    'blink_network_device_leds',
    'update_network_device_management_interface_settings',
    'wan_1',
    'wan_2',
    'update_network_device_wireless_radio_settings',
    'update_network_firewalled_service',
    'create_network_floor_plan',
    'center',
    'bottom_left_corner',
    'bottom_right_corner',
    'top_left_corner',
    'top_right_corner',
    'update_network_floor_plan',
    'center_1',
    'create_network_group_policy',
    'scheduling',
    'monday',
    'tuesday',
    'wednesday',
    'thursday',
    'friday',
    'saturday',
    'sunday',
    'bandwidth',
    'bandwidth_limits',
    'firewall_and_traffic_shaping',
    'traffic_shaping_rule',
    'definition',
    'per_client_bandwidth_limits',
    'bandwidth_limits_1',
    'l_3_firewall_rule',
    'l_7_firewall_rule',
    'content_filtering',
    'allowed_url_patterns',
    'blocked_url_patterns',
    'blocked_url_categories',
    'vlan_tagging',
    'bonjour_forwarding',
    'rule_1',
    'update_network_group_policy',
    'create_network_http_server',
    'create_network_http_servers_webhook_test',
    'update_network_http_server',
    'update_network_l_3_firewall_rules',
    'update_network_l_7_firewall_rules',
    'rule_4',
    'update_network_netflow_settings',
    'update_network_one_to_many_nat_rules',
    'rule_5',
    'update_network_one_to_one_nat_rules',
    'rule_6',
    'create_network_pii_request',
    'update_network_port_forwarding_rules',
    'rule_7',
    'update_network_security_intrusion_settings',
    'protected_networks',
    'update_network_security_malware_settings',
    'allowed_url',
    'allowed_file',
    'update_network_site_to_site_vpn',
    'hub',
    'subnet',
    'create_network_sm_app_polaris',
    'update_network_sm_app_polaris',
    'create_network_sm_bypass_activation_lock_attempt',
    'update_network_sm_device_fields',
    'device_fields',
    'wipe_network_sm_device',
    'checkin_network_sm_devices',
    'move_network_sm_devices',
    'update_network_sm_devices_tags',
    'create_network_sm_profile_clarity',
    'vendor_config',
    'update_network_sm_profile_clarity',
    'add_network_sm_profile_clarity',
    'create_network_sm_profile_umbrella',
    'provider_configuration',
    'update_network_sm_profile_umbrella',
    'add_network_sm_profile_umbrella',
    'create_network_sm_target_group',
    'update_network_sm_target_group',
    'update_network_snmp_settings',
    'user',
    'update_network_ssid',
    'radius_server',
    'radius_accounting_server',
    'ap_tags_and_vlan_id',
    'update_network_ssid_l_3_firewall_rules',
    'rule_8',
    'update_network_ssid_splash_settings',
    'update_network_ssid_traffic_shaping',
    'rule_9',
    'create_network_static_route',
    'update_network_static_route',
    'update_network_switch_access_control_lists',
    'rule_10',
    'create_network_switch_port_schedule',
    'port_schedule',
    'update_network_switch_port_schedule',
    'update_network_switch_settings',
    'power_exception',
    'update_network_switch_settings_dhcp_server_policy',
    'update_network_switch_settings_dscp_to_cos_mappings',
    'mapping',
    'update_network_switch_settings_mtu',
    'override',
    'create_network_switch_settings_qos_rule',
    'update_network_switch_settings_qos_rules_order',
    'update_network_switch_settings_qos_rule',
    'update_network_switch_settings_storm_control',
    'update_network_switch_settings_stp',
    'stp_bridge_priority',
    'create_network_switch_stack',
    'add_network_switch_stack',
    'remove_network_switch_stack',
    'update_network_syslog_servers',
    'server',
    'update_network_traffic_analysis_settings',
    'custom_pie_chart_item',
    'update_network_traffic_shaping',
    'rule_11',
    'update_network_uplink_settings',
    'bandwidth_limits_6',
    'wan_11',
    'wan_21',
    'cellular',
    'create_network_vlan',
    'update_network_vlan',
    'reserved_ip_range',
    'dhcp_option',
    'update_network_vlans_enabled_state',
    'update_network_warm_spare_settings',
    'create_network_wireless_rf_profile',
    'ap_band_settings',
    'two_four_ghz_settings',
    'five_ghz_settings',
    'update_network_wireless_rf_profile',
    'ap_band_settings_1',
    'two_four_ghz_settings_1',
    'five_ghz_settings_1',
    'update_network_wireless_settings',
    'lock_network_sm_devices',
    'create_organization',
    'update_organization',
    'create_organization_action_batch',
    'action',
    'update_organization_action_batch',
    'create_organization_admin',
    'tag',
    'network',
    'update_organization_admin',
    'create_organization_branding_policy',
    'admin_settings',
    'help_settings',
    'update_organization_branding_policies_priorities',
    'update_organization_branding_policy',
    'help_settings_1',
    'claim_organization',
    'license',
    'clone_organization',
    'assign_organization_licenses_seats',
    'move_organization_licenses',
    'move_organization_licenses_seats',
    'renew_organization_licenses_seats',
    'update_organization_license',
    'create_organization_network',
    'combine_organization_networks',
    'create_organization_saml_role',
    'tag_2',
    'network_2',
    'update_organization_saml_role',
    'update_organization_security_intrusion_settings',
    'whitelisted_rule',
    'update_organization_snmp',
    'update_organization_third_party_vpn_peers',
    'peer',
    'ipsec_policies',
    'update_organization_vpn_firewall_rules',
    'rule_12',
    'object_type_enum',
    'udld_enum',
    'major_minor_assignment_mode_enum',
    'policy_enum',
    'protocol_enum',
    'uplink_enum',
    'wan_enabled_enum',
    'access_enum',
    'settings_enum',
    'settings_1_enum',
    'type_enum',
    'policy_1_enum',
    'type_1_enum',
    'settings_2_enum',
    'settings_4_enum',
    'splash_auth_settings_enum',
    'settings_5_enum',
    'settings_6_enum',
    'service_enum',
    'policy_4_enum',
    'type_4_enum',
    'type_5_enum',
    'mode_enum',
    'access_1_enum',
    'ssid_number_enum',
    'auth_mode_enum',
    'enterprise_admin_access_enum',
    'encryption_mode_enum',
    'wpa_encryption_mode_enum',
    'splash_page_enum',
    'radius_failover_policy_enum',
    'radius_load_balancing_policy_enum',
    'policy_6_enum',
    'ip_version_enum',
    'protocol_3_enum',
    'power_type_enum',
    'default_policy_enum',
    'protocol_4_enum',
    'protocol_5_enum',
    'mode_1_enum',
    'type_7_enum',
    'dhcp_handling_enum',
    'dhcp_lease_time_enum',
    'type_9_enum',
    'min_bitrate_type_enum',
    'band_selection_type_enum',
    'band_operation_mode_enum',
    'min_bitrate_type_1_enum',
    'band_selection_type_1_enum',
    'band_operation_mode_1_enum',
    'org_access_enum',
    'applies_to_enum',
    'help_tab_enum',
    'get_help_subtab_enum',
    'community_subtab_enum',
    'cases_subtab_enum',
    'data_protection_requests_subtab_enum',
    'universal_search_knowledge_base_search_enum',
    'new_features_subtab_enum',
    'firewall_info_subtab_enum',
    'api_docs_subtab_enum',
    'hardware_replacements_subtab_enum',
    'sm_forums_enum',
    'mode_2_enum',
    'state_enum',
    'v_3_auth_mode_enum',
    'v_3_priv_mode_enum',
]


# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class TypeEnum(object):

    """Implementation of the 'Type' enum.

    The type of definition. Can be one of 'application',
    'applicationCategory', 'host', 'port', 'ipRange' or 'localNet'.

    Attributes:
        APPLICATION: TODO: type description here.
        APPLICATIONCATEGORY: TODO: type description here.
        HOST: TODO: type description here.
        PORT: TODO: type description here.
        IPRANGE: TODO: type description here.
        LOCALNET: TODO: type description here.

    """

    APPLICATION = 'application'

    APPLICATIONCATEGORY = 'applicationCategory'

    HOST = 'host'

    PORT = 'port'

    IPRANGE = 'ipRange'

    LOCALNET = 'localNet'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkContentFiltering(object):

    """Implementation of the 'updateNetworkContentFiltering' model.

    TODO: type model description here.

    Attributes:
        allowed_url_patterns (list of string): A whitelist of URL patterns to
            allow
        blocked_url_patterns (list of string): A blacklist of URL patterns to
            block
        blocked_url_categories (list of string): A list of URL categories to
            block
        url_category_list_size (string): URL category list size which is
            either 'topSites' or 'fullList'

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "allowed_url_patterns":'allowedUrlPatterns',
        "blocked_url_patterns":'blockedUrlPatterns',
        "blocked_url_categories":'blockedUrlCategories',
        "url_category_list_size":'urlCategoryListSize'
    }

    def __init__(self,
                 allowed_url_patterns=None,
                 blocked_url_patterns=None,
                 blocked_url_categories=None,
                 url_category_list_size=None):
        """Constructor for the UpdateNetworkContentFiltering class"""

        # Initialize members of the class
        self.allowed_url_patterns = allowed_url_patterns
        self.blocked_url_patterns = blocked_url_patterns
        self.blocked_url_categories = blocked_url_categories
        self.url_category_list_size = url_category_list_size


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        allowed_url_patterns = dictionary.get('allowedUrlPatterns')
        blocked_url_patterns = dictionary.get('blockedUrlPatterns')
        blocked_url_categories = dictionary.get('blockedUrlCategories')
        url_category_list_size = dictionary.get('urlCategoryListSize')

        # Return an object of this model
        return cls(allowed_url_patterns,
                   blocked_url_patterns,
                   blocked_url_categories,
                   url_category_list_size)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateOrganizationSnmp(object):

    """Implementation of the 'updateOrganizationSnmp' model.

    TODO: type model description here.

    Attributes:
        v_2_c_enabled (bool): Boolean indicating whether SNMP version 2c is
            enabled for the organization.
        v_3_enabled (bool): Boolean indicating whether SNMP version 3 is
            enabled for the organization.
        v_3_auth_mode (V3AuthModeEnum): The SNMP version 3 authentication
            mode. Can be either 'MD5' or 'SHA'.
        v_3_auth_pass (string): The SNMP version 3 authentication password.
            Must be at least 8 characters if specified.
        v_3_priv_mode (V3PrivModeEnum): The SNMP version 3 privacy mode. Can
            be either 'DES' or 'AES128'.
        v_3_priv_pass (string): The SNMP version 3 privacy password. Must be
            at least 8 characters if specified.
        peer_ips (string): The IPs that are allowed to access the SNMP server.
            This list should be IPv4 addresses separated by semi-colons (ie.
            "1.2.3.4;2.3.4.5").

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "v_2_c_enabled":'v2cEnabled',
        "v_3_enabled":'v3Enabled',
        "v_3_auth_mode":'v3AuthMode',
        "v_3_auth_pass":'v3AuthPass',
        "v_3_priv_mode":'v3PrivMode',
        "v_3_priv_pass":'v3PrivPass',
        "peer_ips":'peerIps'
    }

    def __init__(self,
                 v_2_c_enabled=None,
                 v_3_enabled=None,
                 v_3_auth_mode=None,
                 v_3_auth_pass=None,
                 v_3_priv_mode=None,
                 v_3_priv_pass=None,
                 peer_ips=None):
        """Constructor for the UpdateOrganizationSnmp class"""

        # Initialize members of the class
        self.v_2_c_enabled = v_2_c_enabled
        self.v_3_enabled = v_3_enabled
        self.v_3_auth_mode = v_3_auth_mode
        self.v_3_auth_pass = v_3_auth_pass
        self.v_3_priv_mode = v_3_priv_mode
        self.v_3_priv_pass = v_3_priv_pass
        self.peer_ips = peer_ips


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        v_2_c_enabled = dictionary.get('v2cEnabled')
        v_3_enabled = dictionary.get('v3Enabled')
        v_3_auth_mode = dictionary.get('v3AuthMode')
        v_3_auth_pass = dictionary.get('v3AuthPass')
        v_3_priv_mode = dictionary.get('v3PrivMode')
        v_3_priv_pass = dictionary.get('v3PrivPass')
        peer_ips = dictionary.get('peerIps')

        # Return an object of this model
        return cls(v_2_c_enabled,
                   v_3_enabled,
                   v_3_auth_mode,
                   v_3_auth_pass,
                   v_3_priv_mode,
                   v_3_priv_pass,
                   peer_ips)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class ServiceEnum(object):

    """Implementation of the 'Service' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_ALL SERVICES: TODO: type description here.
        AIRPLAY: TODO: type description here.
        AFP: TODO: type description here.
        BITTORRENT: TODO: type description here.
        FTP: TODO: type description here.
        ICHAT: TODO: type description here.
        ITUNES: TODO: type description here.
        PRINTERS: TODO: type description here.
        SAMBA: TODO: type description here.
        SCANNERS: TODO: type description here.
        SSH: TODO: type description here.

    """

    ENUM_ALL_SERVICES = 'All Services'

    AIRPLAY = 'AirPlay'

    AFP = 'AFP'

    BITTORRENT = 'BitTorrent'

    FTP = 'FTP'

    ICHAT = 'iChat'

    ITUNES = 'iTunes'

    PRINTERS = 'Printers'

    SAMBA = 'Samba'

    SCANNERS = 'Scanners'

    SSH = 'SSH'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkSwitchSettingsStormControl(object):

    """Implementation of the 'updateNetworkSwitchSettingsStormControl' model.

    TODO: type model description here.

    Attributes:
        broadcast_threshold (int): Percentage (1 to 99) of total available
            port bandwidth for broadcast traffic type. Default value 100
            percent rate is to clear the configuration.
        multicast_threshold (int): Percentage (1 to 99) of total available
            port bandwidth for multicast traffic type. Default value 100
            percent rate is to clear the configuration.
        unknown_unicast_threshold (int): Percentage (1 to 99) of total
            available port bandwidth for unknown unicast (dlf-destination
            lookup failure) traffic type. Default value 100 percent rate is to
            clear the configuration.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "broadcast_threshold":'broadcastThreshold',
        "multicast_threshold":'multicastThreshold',
        "unknown_unicast_threshold":'unknownUnicastThreshold'
    }

    def __init__(self,
                 broadcast_threshold=None,
                 multicast_threshold=None,
                 unknown_unicast_threshold=None):
        """Constructor for the UpdateNetworkSwitchSettingsStormControl class"""

        # Initialize members of the class
        self.broadcast_threshold = broadcast_threshold
        self.multicast_threshold = multicast_threshold
        self.unknown_unicast_threshold = unknown_unicast_threshold


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        broadcast_threshold = dictionary.get('broadcastThreshold')
        multicast_threshold = dictionary.get('multicastThreshold')
        unknown_unicast_threshold = dictionary.get('unknownUnicastThreshold')

        # Return an object of this model
        return cls(broadcast_threshold,
                   multicast_threshold,
                   unknown_unicast_threshold)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.allowed_url_patterns
import test_meraki.models.blocked_url_patterns
import test_meraki.models.blocked_url_categories

class ContentFiltering(object):

    """Implementation of the 'ContentFiltering' model.

    The content filtering settings for your group policy

    Attributes:
        allowed_url_patterns (AllowedUrlPatterns): Settings for whitelisted
            URL patterns
        blocked_url_patterns (BlockedUrlPatterns): Settings for blacklisted
            URL patterns
        blocked_url_categories (BlockedUrlCategories): Settings for
            blacklisted URL categories

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "allowed_url_patterns":'allowedUrlPatterns',
        "blocked_url_patterns":'blockedUrlPatterns',
        "blocked_url_categories":'blockedUrlCategories'
    }

    def __init__(self,
                 allowed_url_patterns=None,
                 blocked_url_patterns=None,
                 blocked_url_categories=None):
        """Constructor for the ContentFiltering class"""

        # Initialize members of the class
        self.allowed_url_patterns = allowed_url_patterns
        self.blocked_url_patterns = blocked_url_patterns
        self.blocked_url_categories = blocked_url_categories


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        allowed_url_patterns = test_meraki.models.allowed_url_patterns.AllowedUrlPatterns.from_dictionary(dictionary.get('allowedUrlPatterns')) if dictionary.get('allowedUrlPatterns') else None
        blocked_url_patterns = test_meraki.models.blocked_url_patterns.BlockedUrlPatterns.from_dictionary(dictionary.get('blockedUrlPatterns')) if dictionary.get('blockedUrlPatterns') else None
        blocked_url_categories = test_meraki.models.blocked_url_categories.BlockedUrlCategories.from_dictionary(dictionary.get('blockedUrlCategories')) if dictionary.get('blockedUrlCategories') else None

        # Return an object of this model
        return cls(allowed_url_patterns,
                   blocked_url_patterns,
                   blocked_url_categories)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class MVSenseController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_device_camera_analytics_live(self,
                                         serial):
        """Does a GET request to /devices/{serial}/camera/analytics/live.

        Returns live state from camera of analytics zones

        Args:
            serial (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/devices/{serial}/camera/analytics/live'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_device_camera_analytics_overview(self,
                                             serial,
                                             t_0=None,
                                             t_1=None,
                                             timespan=None,
                                             object_type=None):
        """Does a GET request to /devices/{serial}/camera/analytics/overview.

        Returns an overview of aggregate analytics data for a timespan

        Args:
            serial (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 365 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 7 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 7 days. The default is 1 hour.
            object_type (ObjectTypeEnum, optional): [optional] The object type
                for which analytics will be retrieved. The default object type
                is person. The available types are [person, vehicle].

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/devices/{serial}/camera/analytics/overview'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'objectType': object_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_device_camera_analytics_recent(self,
                                           serial,
                                           object_type=None):
        """Does a GET request to /devices/{serial}/camera/analytics/recent.

        Returns most recent record for analytics zones

        Args:
            serial (string): TODO: type description here. Example: 
            object_type (ObjectTypeEnum, optional): [optional] The object type
                for which analytics will be retrieved. The default object type
                is person. The available types are [person, vehicle].

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/devices/{serial}/camera/analytics/recent'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'objectType': object_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_device_camera_analytics_zones(self,
                                          serial):
        """Does a GET request to /devices/{serial}/camera/analytics/zones.

        Returns all configured analytic zones for this camera

        Args:
            serial (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/devices/{serial}/camera/analytics/zones'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_device_camera_analytics_zone_history(self,
                                                 serial,
                                                 zone_id,
                                                 t_0=None,
                                                 t_1=None,
                                                 timespan=None,
                                                 resolution=None,
                                                 object_type=None):
        """Does a GET request to /devices/{serial}/camera/analytics/zones/{zoneId}/history.

        Return historical records for analytic zones

        Args:
            serial (string): TODO: type description here. Example: 
            zone_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 365 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 14 hours after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 14 hours. The default is 1 hour.
            resolution (int, optional): The time resolution in seconds for
                returned data. The valid resolutions are: 60. The default is
                60.
            object_type (ObjectTypeEnum, optional): [optional] The object type
                for which analytics will be retrieved. The default object type
                is person. The available types are [person, vehicle].

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/devices/{serial}/camera/analytics/zones/{zoneId}/history'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'serial': serial,
            'zoneId': zone_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'resolution': resolution,
            'objectType': object_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class SwitchSettingsController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_network_switch_settings(self,
                                    network_id):
        """Does a GET request to /networks/{networkId}/switch/settings.

        Returns the switch network settings

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_switch_settings(self,
                                       network_id,
                                       update_network_switch_settings=None):
        """Does a PUT request to /networks/{networkId}/switch/settings.

        Update switch network settings

        Args:
            network_id (string): TODO: type description here. Example: 
            update_network_switch_settings (UpdateNetworkSwitchSettings,
                optional): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_switch_settings))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_switch_settings_dhcp_server_policy(self,
                                                       network_id):
        """Does a GET request to /networks/{networkId}/switch/settings/dhcpServerPolicy.

        Return the DHCP server policy

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/dhcpServerPolicy'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_switch_settings_dhcp_server_policy(self,
                                                          network_id,
                                                          update_network_switch_settings_dhcp_server_policy=None):
        """Does a PUT request to /networks/{networkId}/switch/settings/dhcpServerPolicy.

        Update the DHCP server policy

        Args:
            network_id (string): TODO: type description here. Example: 
            update_network_switch_settings_dhcp_server_policy
                (UpdateNetworkSwitchSettingsDhcpServerPolicy, optional): TODO:
                type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/dhcpServerPolicy'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_switch_settings_dhcp_server_policy))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_switch_settings_dscp_to_cos_mappings(self,
                                                         network_id):
        """Does a GET request to /networks/{networkId}/switch/settings/dscpToCosMappings.

        Return the DSCP to CoS mappings

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/dscpToCosMappings'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_switch_settings_dscp_to_cos_mappings(self,
                                                            network_id,
                                                            update_network_switch_settings_dscp_to_cos_mappings):
        """Does a PUT request to /networks/{networkId}/switch/settings/dscpToCosMappings.

        Update the DSCP to CoS mappings

        Args:
            network_id (string): TODO: type description here. Example: 
            update_network_switch_settings_dscp_to_cos_mappings
                (UpdateNetworkSwitchSettingsDscpToCosMappings): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/dscpToCosMappings'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_switch_settings_dscp_to_cos_mappings))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_switch_settings_mtu(self,
                                        network_id):
        """Does a GET request to /networks/{networkId}/switch/settings/mtu.

        Return the MTU configuration

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/mtu'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_switch_settings_mtu(self,
                                           network_id,
                                           update_network_switch_settings_mtu=None):
        """Does a PUT request to /networks/{networkId}/switch/settings/mtu.

        Update the MTU configuration

        Args:
            network_id (string): TODO: type description here. Example: 
            update_network_switch_settings_mtu
                (UpdateNetworkSwitchSettingsMtu, optional): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/mtu'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_switch_settings_mtu))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_switch_settings_qos_rules(self,
                                              network_id):
        """Does a GET request to /networks/{networkId}/switch/settings/qosRules.

        List quality of service rules

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/qosRules'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_network_switch_settings_qos_rule(self,
                                                network_id,
                                                create_network_switch_settings_qos_rule):
        """Does a POST request to /networks/{networkId}/switch/settings/qosRules.

        Add a quality of service rule

        Args:
            network_id (string): TODO: type description here. Example: 
            create_network_switch_settings_qos_rule
                (CreateNetworkSwitchSettingsQosRule): TODO: type description
                here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/qosRules'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_network_switch_settings_qos_rule))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_switch_settings_qos_rules_order(self,
                                                    network_id):
        """Does a GET request to /networks/{networkId}/switch/settings/qosRules/order.

        Return the quality of service rule IDs by order in which they will be
        processed by the switch

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/qosRules/order'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_switch_settings_qos_rules_order(self,
                                                       network_id,
                                                       update_network_switch_settings_qos_rules_order):
        """Does a PUT request to /networks/{networkId}/switch/settings/qosRules/order.

        Update the order in which the rules should be processed by the switch

        Args:
            network_id (string): TODO: type description here. Example: 
            update_network_switch_settings_qos_rules_order
                (UpdateNetworkSwitchSettingsQosRulesOrder): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/qosRules/order'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_switch_settings_qos_rules_order))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_switch_settings_qos_rule(self,
                                             network_id,
                                             qos_rule_id):
        """Does a GET request to /networks/{networkId}/switch/settings/qosRules/{qosRuleId}.

        Return a quality of service rule

        Args:
            network_id (string): TODO: type description here. Example: 
            qos_rule_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/qosRules/{qosRuleId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'qosRuleId': qos_rule_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def delete_network_switch_settings_qos_rule(self,
                                                network_id,
                                                qos_rule_id):
        """Does a DELETE request to /networks/{networkId}/switch/settings/qosRules/{qosRuleId}.

        Delete a quality of service rule

        Args:
            network_id (string): TODO: type description here. Example: 
            qos_rule_id (string): TODO: type description here. Example: 

        Returns:
            void: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/qosRules/{qosRuleId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'qosRuleId': qos_rule_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.delete(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

    def update_network_switch_settings_qos_rule(self,
                                                network_id,
                                                qos_rule_id,
                                                update_network_switch_settings_qos_rule=None):
        """Does a PUT request to /networks/{networkId}/switch/settings/qosRules/{qosRuleId}.

        Update a quality of service rule

        Args:
            network_id (string): TODO: type description here. Example: 
            qos_rule_id (string): TODO: type description here. Example: 
            update_network_switch_settings_qos_rule
                (UpdateNetworkSwitchSettingsQosRule, optional): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/qosRules/{qosRuleId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'qosRuleId': qos_rule_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_switch_settings_qos_rule))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_switch_settings_storm_control(self,
                                                  network_id):
        """Does a GET request to /networks/{networkId}/switch/settings/stormControl.

        Return the global enhanced storm control configuration

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/stormControl'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_switch_settings_storm_control(self,
                                                     network_id,
                                                     update_network_switch_settings_storm_control=None):
        """Does a PUT request to /networks/{networkId}/switch/settings/stormControl.

        Update the global enhanced storm control configuration

        Args:
            network_id (string): TODO: type description here. Example: 
            update_network_switch_settings_storm_control
                (UpdateNetworkSwitchSettingsStormControl, optional): TODO:
                type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/stormControl'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_switch_settings_storm_control))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_switch_settings_stp(self,
                                        network_id):
        """Does a GET request to /networks/{networkId}/switch/settings/stp.

        Returns STP settings

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/stp'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_switch_settings_stp(self,
                                           network_id,
                                           update_network_switch_settings_stp=None):
        """Does a PUT request to /networks/{networkId}/switch/settings/stp.

        Updates STP settings

        Args:
            network_id (string): TODO: type description here. Example: 
            update_network_switch_settings_stp
                (UpdateNetworkSwitchSettingsStp, optional): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/switch/settings/stp'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_switch_settings_stp))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.wan_11
import test_meraki.models.wan_21
import test_meraki.models.cellular

class BandwidthLimits6(object):

    """Implementation of the 'BandwidthLimits6' model.

    A mapping of uplinks to their bandwidth settings (be sure to check which
    uplinks are supported for your network)

    Attributes:
        wan_1 (Wan11): The bandwidth settings for the 'wan1' uplink
        wan_2 (Wan21): The bandwidth settings for the 'wan2' uplink
        cellular (Cellular): The bandwidth settings for the 'cellular' uplink

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "wan_1":'wan1',
        "wan_2":'wan2',
        "cellular":'cellular'
    }

    def __init__(self,
                 wan_1=None,
                 wan_2=None,
                 cellular=None):
        """Constructor for the BandwidthLimits6 class"""

        # Initialize members of the class
        self.wan_1 = wan_1
        self.wan_2 = wan_2
        self.cellular = cellular


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        wan_1 = test_meraki.models.wan_11.Wan11.from_dictionary(dictionary.get('wan1')) if dictionary.get('wan1') else None
        wan_2 = test_meraki.models.wan_21.Wan21.from_dictionary(dictionary.get('wan2')) if dictionary.get('wan2') else None
        cellular = test_meraki.models.cellular.Cellular.from_dictionary(dictionary.get('cellular')) if dictionary.get('cellular') else None

        # Return an object of this model
        return cls(wan_1,
                   wan_2,
                   cellular)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class WirelessHealthController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_network_clients_connection_stats(self,
                                             network_id,
                                             t_0=None,
                                             t_1=None,
                                             timespan=None,
                                             ssid=None,
                                             vlan=None,
                                             ap_tag=None):
        """Does a GET request to /networks/{networkId}/clients/connectionStats.

        Aggregated connectivity info for this network, grouped by clients

        Args:
            network_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 180 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 7 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 7 days.
            ssid (int, optional): Filter results by SSID
            vlan (int, optional): Filter results by VLAN
            ap_tag (string, optional): Filter results by AP Tag

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/connectionStats'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'ssid': ssid,
            'vlan': vlan,
            'apTag': ap_tag
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_clients_latency_stats(self,
                                          network_id,
                                          t_0=None,
                                          t_1=None,
                                          timespan=None,
                                          ssid=None,
                                          vlan=None,
                                          ap_tag=None,
                                          fields=None):
        """Does a GET request to /networks/{networkId}/clients/latencyStats.

        Aggregated latency info for this network, grouped by clients

        Args:
            network_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 180 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 7 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 7 days.
            ssid (int, optional): Filter results by SSID
            vlan (int, optional): Filter results by VLAN
            ap_tag (string, optional): Filter results by AP Tag
            fields (string, optional): Partial selection: If present, this
                call will return only the selected fields of
                ["rawDistribution", "avg"]. All fields will be returned by
                default. Selected fields must be entered as a comma separated
                string.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/latencyStats'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'ssid': ssid,
            'vlan': vlan,
            'apTag': ap_tag,
            'fields': fields
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_client_connection_stats(self,
                                            network_id,
                                            client_id,
                                            t_0=None,
                                            t_1=None,
                                            timespan=None,
                                            ssid=None,
                                            vlan=None,
                                            ap_tag=None):
        """Does a GET request to /networks/{networkId}/clients/{clientId}/connectionStats.

        Aggregated connectivity info for a given client on this network.
        Clients are identified by their MAC.

        Args:
            network_id (string): TODO: type description here. Example: 
            client_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 180 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 7 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 7 days.
            ssid (int, optional): Filter results by SSID
            vlan (int, optional): Filter results by VLAN
            ap_tag (string, optional): Filter results by AP Tag

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/{clientId}/connectionStats'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'clientId': client_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'ssid': ssid,
            'vlan': vlan,
            'apTag': ap_tag
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_client_latency_stats(self,
                                         network_id,
                                         client_id,
                                         t_0=None,
                                         t_1=None,
                                         timespan=None,
                                         ssid=None,
                                         vlan=None,
                                         ap_tag=None,
                                         fields=None):
        """Does a GET request to /networks/{networkId}/clients/{clientId}/latencyStats.

        Aggregated latency info for a given client on this network. Clients
        are identified by their MAC.

        Args:
            network_id (string): TODO: type description here. Example: 
            client_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 180 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 7 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 7 days.
            ssid (int, optional): Filter results by SSID
            vlan (int, optional): Filter results by VLAN
            ap_tag (string, optional): Filter results by AP Tag
            fields (string, optional): Partial selection: If present, this
                call will return only the selected fields of
                ["rawDistribution", "avg"]. All fields will be returned by
                default. Selected fields must be entered as a comma separated
                string.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/{clientId}/latencyStats'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'clientId': client_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'ssid': ssid,
            'vlan': vlan,
            'apTag': ap_tag,
            'fields': fields
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_connection_stats(self,
                                     network_id,
                                     t_0=None,
                                     t_1=None,
                                     timespan=None,
                                     ssid=None,
                                     vlan=None,
                                     ap_tag=None):
        """Does a GET request to /networks/{networkId}/connectionStats.

        Aggregated connectivity info for this network

        Args:
            network_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 180 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 7 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 7 days.
            ssid (int, optional): Filter results by SSID
            vlan (int, optional): Filter results by VLAN
            ap_tag (string, optional): Filter results by AP Tag

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/connectionStats'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'ssid': ssid,
            'vlan': vlan,
            'apTag': ap_tag
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_devices_connection_stats(self,
                                             network_id,
                                             t_0=None,
                                             t_1=None,
                                             timespan=None,
                                             ssid=None,
                                             vlan=None,
                                             ap_tag=None):
        """Does a GET request to /networks/{networkId}/devices/connectionStats.

        Aggregated connectivity info for this network, grouped by node

        Args:
            network_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 180 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 7 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 7 days.
            ssid (int, optional): Filter results by SSID
            vlan (int, optional): Filter results by VLAN
            ap_tag (string, optional): Filter results by AP Tag

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/connectionStats'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'ssid': ssid,
            'vlan': vlan,
            'apTag': ap_tag
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_devices_latency_stats(self,
                                          network_id,
                                          t_0=None,
                                          t_1=None,
                                          timespan=None,
                                          ssid=None,
                                          vlan=None,
                                          ap_tag=None,
                                          fields=None):
        """Does a GET request to /networks/{networkId}/devices/latencyStats.

        Aggregated latency info for this network, grouped by node

        Args:
            network_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 180 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 7 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 7 days.
            ssid (int, optional): Filter results by SSID
            vlan (int, optional): Filter results by VLAN
            ap_tag (string, optional): Filter results by AP Tag
            fields (string, optional): Partial selection: If present, this
                call will return only the selected fields of
                ["rawDistribution", "avg"]. All fields will be returned by
                default. Selected fields must be entered as a comma separated
                string.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/latencyStats'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'ssid': ssid,
            'vlan': vlan,
            'apTag': ap_tag,
            'fields': fields
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_device_connection_stats(self,
                                            network_id,
                                            serial,
                                            t_0=None,
                                            t_1=None,
                                            timespan=None,
                                            ssid=None,
                                            vlan=None,
                                            ap_tag=None):
        """Does a GET request to /networks/{networkId}/devices/{serial}/connectionStats.

        Aggregated connectivity info for a given AP on this network

        Args:
            network_id (string): TODO: type description here. Example: 
            serial (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 180 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 7 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 7 days.
            ssid (int, optional): Filter results by SSID
            vlan (int, optional): Filter results by VLAN
            ap_tag (string, optional): Filter results by AP Tag

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/{serial}/connectionStats'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'ssid': ssid,
            'vlan': vlan,
            'apTag': ap_tag
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_device_latency_stats(self,
                                         network_id,
                                         serial,
                                         t_0=None,
                                         t_1=None,
                                         timespan=None,
                                         ssid=None,
                                         vlan=None,
                                         ap_tag=None,
                                         fields=None):
        """Does a GET request to /networks/{networkId}/devices/{serial}/latencyStats.

        Aggregated latency info for a given AP on this network

        Args:
            network_id (string): TODO: type description here. Example: 
            serial (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 180 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 7 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 7 days.
            ssid (int, optional): Filter results by SSID
            vlan (int, optional): Filter results by VLAN
            ap_tag (string, optional): Filter results by AP Tag
            fields (string, optional): Partial selection: If present, this
                call will return only the selected fields of
                ["rawDistribution", "avg"]. All fields will be returned by
                default. Selected fields must be entered as a comma separated
                string.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/devices/{serial}/latencyStats'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'ssid': ssid,
            'vlan': vlan,
            'apTag': ap_tag,
            'fields': fields
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_failed_connections(self,
                                       network_id,
                                       t_0=None,
                                       t_1=None,
                                       timespan=None,
                                       ssid=None,
                                       vlan=None,
                                       ap_tag=None,
                                       serial=None,
                                       client_id=None):
        """Does a GET request to /networks/{networkId}/failedConnections.

        List of all failed client connection events on this network in a given
        time range

        Args:
            network_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 180 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 7 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 7 days.
            ssid (int, optional): Filter results by SSID
            vlan (int, optional): Filter results by VLAN
            ap_tag (string, optional): Filter results by AP Tag
            serial (string, optional): Filter by AP
            client_id (string, optional): Filter by client MAC

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/failedConnections'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'ssid': ssid,
            'vlan': vlan,
            'apTag': ap_tag,
            'serial': serial,
            'clientId': client_id
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_latency_stats(self,
                                  network_id,
                                  t_0=None,
                                  t_1=None,
                                  timespan=None,
                                  ssid=None,
                                  vlan=None,
                                  ap_tag=None,
                                  fields=None):
        """Does a GET request to /networks/{networkId}/latencyStats.

        Aggregated latency info for this network

        Args:
            network_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 180 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 7 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 7 days.
            ssid (int, optional): Filter results by SSID
            vlan (int, optional): Filter results by VLAN
            ap_tag (string, optional): Filter results by AP Tag
            fields (string, optional): Partial selection: If present, this
                call will return only the selected fields of
                ["rawDistribution", "avg"]. All fields will be returned by
                default. Selected fields must be entered as a comma separated
                string.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/latencyStats'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'ssid': ssid,
            'vlan': vlan,
            'apTag': ap_tag,
            'fields': fields
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Policy4Enum(object):

    """Implementation of the 'Policy4' enum.

    'Deny' traffic specified by this rule

    Attributes:
        DENY: TODO: type description here.

    """

    DENY = 'deny'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.scheduling
import test_meraki.models.bandwidth
import test_meraki.models.firewall_and_traffic_shaping
import test_meraki.models.content_filtering
import test_meraki.models.vlan_tagging
import test_meraki.models.bonjour_forwarding

class CreateNetworkGroupPolicy(object):

    """Implementation of the 'createNetworkGroupPolicy' model.

    TODO: type model description here.

    Attributes:
        name (string): The name for your group policy. Required.
        scheduling (Scheduling): The schedule for the group policy. Schedules
            are applied to days of the week.
        bandwidth (Bandwidth): The bandwidth settings for clients bound to
            your group policy.
        firewall_and_traffic_shaping (FirewallAndTrafficShaping): The firewall
            and traffic shaping rules and settings for your policy.
        content_filtering (ContentFiltering): The content filtering settings
            for your group policy
        splash_auth_settings (SplashAuthSettingsEnum): Whether clients bound
            to your policy will bypass splash authorization or behave
            according to the network's rules. Can be one of 'network default'
            or 'bypass'. Only available if your network has a wireless
            configuration.
        vlan_tagging (VlanTagging): The VLAN tagging settings for your group
            policy. Only available if your network has a wireless
            configuration.
        bonjour_forwarding (BonjourForwarding): The Bonjour settings for your
            group policy. Only valid if your network has a wireless
            configuration.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "scheduling":'scheduling',
        "bandwidth":'bandwidth',
        "firewall_and_traffic_shaping":'firewallAndTrafficShaping',
        "content_filtering":'contentFiltering',
        "splash_auth_settings":'splashAuthSettings',
        "vlan_tagging":'vlanTagging',
        "bonjour_forwarding":'bonjourForwarding'
    }

    def __init__(self,
                 name=None,
                 scheduling=None,
                 bandwidth=None,
                 firewall_and_traffic_shaping=None,
                 content_filtering=None,
                 splash_auth_settings=None,
                 vlan_tagging=None,
                 bonjour_forwarding=None):
        """Constructor for the CreateNetworkGroupPolicy class"""

        # Initialize members of the class
        self.name = name
        self.scheduling = scheduling
        self.bandwidth = bandwidth
        self.firewall_and_traffic_shaping = firewall_and_traffic_shaping
        self.content_filtering = content_filtering
        self.splash_auth_settings = splash_auth_settings
        self.vlan_tagging = vlan_tagging
        self.bonjour_forwarding = bonjour_forwarding


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        scheduling = test_meraki.models.scheduling.Scheduling.from_dictionary(dictionary.get('scheduling')) if dictionary.get('scheduling') else None
        bandwidth = test_meraki.models.bandwidth.Bandwidth.from_dictionary(dictionary.get('bandwidth')) if dictionary.get('bandwidth') else None
        firewall_and_traffic_shaping = test_meraki.models.firewall_and_traffic_shaping.FirewallAndTrafficShaping.from_dictionary(dictionary.get('firewallAndTrafficShaping')) if dictionary.get('firewallAndTrafficShaping') else None
        content_filtering = test_meraki.models.content_filtering.ContentFiltering.from_dictionary(dictionary.get('contentFiltering')) if dictionary.get('contentFiltering') else None
        splash_auth_settings = dictionary.get('splashAuthSettings')
        vlan_tagging = test_meraki.models.vlan_tagging.VlanTagging.from_dictionary(dictionary.get('vlanTagging')) if dictionary.get('vlanTagging') else None
        bonjour_forwarding = test_meraki.models.bonjour_forwarding.BonjourForwarding.from_dictionary(dictionary.get('bonjourForwarding')) if dictionary.get('bonjourForwarding') else None

        # Return an object of this model
        return cls(name,
                   scheduling,
                   bandwidth,
                   firewall_and_traffic_shaping,
                   content_filtering,
                   splash_auth_settings,
                   vlan_tagging,
                   bonjour_forwarding)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class RadiusAccountingServer(object):

    """Implementation of the 'RadiusAccountingServer' model.

    TODO: type model description here.

    Attributes:
        host (string): IP address to which the APs will send RADIUS accounting
            messages
        port (int): Port on the RADIUS server that is listening for accounting
            messages
        secret (string): Shared key used to authenticate messages between the
            APs and RADIUS server

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "host":'host',
        "secret":'secret',
        "port":'port'
    }

    def __init__(self,
                 host=None,
                 secret=None,
                 port=None):
        """Constructor for the RadiusAccountingServer class"""

        # Initialize members of the class
        self.host = host
        self.port = port
        self.secret = secret


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        host = dictionary.get('host')
        secret = dictionary.get('secret')
        port = dictionary.get('port')

        # Return an object of this model
        return cls(host,
                   secret,
                   port)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class TwoFourGhzSettings1(object):

    """Implementation of the 'TwoFourGhzSettings1' model.

    Settings related to 2.4Ghz band

    Attributes:
        max_power (int): Sets max power (dBm) of 2.4Ghz band. Can be integer
            between 5 and 30.
        min_power (int): Sets min power (dBm) of 2.4Ghz band. Can be integer
            between 5 and 30.
        min_bitrate (float): Sets min bitrate (Mbps) of 2.4Ghz band. Can be
            one of '1', '2', '5.5', '6', '9', '11', '12', '18', '24', '36',
            '48' or '54'.
        valid_auto_channels (list of int): Sets valid auto channels for 2.4Ghz
            band. Can be one of '1', '6' or '11'.
        ax_enabled (bool): Determines whether ax radio on 2.4Ghz band is on or
            off. Can be either true or false. If false, we highly recommend
            disabling band steering.
        rxsop (int): The RX-SOP level controls the sensitivity of the radio.
            It is strongly recommended to use RX-SOP only after     consulting
            a wireless expert. RX-SOP can be configured in the range of -65 to
            -95 (dBm). A value of null will     reset this to the default.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "max_power":'maxPower',
        "min_power":'minPower',
        "min_bitrate":'minBitrate',
        "valid_auto_channels":'validAutoChannels',
        "ax_enabled":'axEnabled',
        "rxsop":'rxsop'
    }

    def __init__(self,
                 max_power=None,
                 min_power=None,
                 min_bitrate=None,
                 valid_auto_channels=None,
                 ax_enabled=None,
                 rxsop=None):
        """Constructor for the TwoFourGhzSettings1 class"""

        # Initialize members of the class
        self.max_power = max_power
        self.min_power = min_power
        self.min_bitrate = min_bitrate
        self.valid_auto_channels = valid_auto_channels
        self.ax_enabled = ax_enabled
        self.rxsop = rxsop


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        max_power = dictionary.get('maxPower')
        min_power = dictionary.get('minPower')
        min_bitrate = dictionary.get('minBitrate')
        valid_auto_channels = dictionary.get('validAutoChannels')
        ax_enabled = dictionary.get('axEnabled')
        rxsop = dictionary.get('rxsop')

        # Return an object of this model
        return cls(max_power,
                   min_power,
                   min_bitrate,
                   valid_auto_channels,
                   ax_enabled,
                   rxsop)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class DefaultPolicyEnum(object):

    """Implementation of the 'DefaultPolicy' enum.

    'allow' or 'block' new DHCP servers. Default value is 'allow'.

    Attributes:
        ALLOW: TODO: type description here.
        BLOCK: TODO: type description here.

    """

    ALLOW = 'allow'

    BLOCK = 'block'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class HelpSettings(object):

    """Implementation of the 'HelpSettings' model.

    Settings for describing the modifications to various Help page features.
    Each property in this object accepts one of
        'default or inherit' (do not modify functionality), 'hide' (remove the
        section from Dashboard), or 'show' (always show
        the section on Dashboard). Some properties in this object also accept
        custom HTML used to replace the section on
        Dashboard; see the documentation for each property to see the allowed
        values.
     Each property defaults to 'default or inherit' when not provided.

    Attributes:
        help_tab (HelpTabEnum): The Help tab, under which all support
            information resides. If this tab is hidden, no other 'Help'
            branding     customizations will be visible. Can be one of
            'default or inherit', 'hide' or 'show'.
        get_help_subtab (GetHelpSubtabEnum): The 'Help -> Get Help' subtab on
            which Cisco Meraki KB, Product Manuals, and Support/Case
            Information are displayed. Note     that if this subtab is hidden,
            branding customizations for the KB on 'Get help', Cisco Meraki
            product documentation,     and support contact info will not be
            visible. Can be one of 'default or inherit', 'hide' or 'show'.
        community_subtab (CommunitySubtabEnum): The 'Help -> Community' subtab
            which provides a link to Meraki Community. Can be one of 'default
            or inherit', 'hide' or 'show'.
        cases_subtab (CasesSubtabEnum): The 'Help -> Cases' Dashboard subtab
            on which Cisco Meraki support cases for this organization can be
            managed. Can be one     of 'default or inherit', 'hide' or
            'show'.
        data_protection_requests_subtab (DataProtectionRequestsSubtabEnum):
            The 'Help -> Data protection requests' Dashboard subtab on which
            requests to delete, restrict, or export end-user data can     be
            audited. Can be one of 'default or inherit', 'hide' or 'show'.
        get_help_subtab_knowledge_base_search (string): The KB search box
            which appears on the Help page. Can be one of 'default or
            inherit', 'hide', 'show', or a replacement custom HTML string.
        universal_search_knowledge_base_search
            (UniversalSearchKnowledgeBaseSearchEnum): The universal search box
            always visible on Dashboard will, by default, present results from
            the Meraki KB. This configures     whether these Meraki KB results
            should be returned. Can be one of 'default or inherit', 'hide' or
            'show'.
        cisco_meraki_product_documentation (string): The 'Product Manuals'
            section of the 'Help -> Get Help' subtab. Can be one of 'default
            or inherit', 'hide', 'show', or a replacement custom HTML string.
        support_contact_info (string): The 'Contact Meraki Support' section of
            the 'Help -> Get Help' subtab. Can be one of 'default or inherit',
            'hide', 'show', or a replacement custom HTML string.
        new_features_subtab (NewFeaturesSubtabEnum): The 'Help -> New
            features' subtab where new Dashboard features are detailed. Can be
            one of 'default or inherit', 'hide' or 'show'.
        firewall_info_subtab (FirewallInfoSubtabEnum): The 'Help -> Firewall
            info' subtab where necessary upstream firewall rules for
            communication to the Cisco Meraki cloud are     listed. Can be one
            of 'default or inherit', 'hide' or 'show'.
        api_docs_subtab (ApiDocsSubtabEnum): The 'Help -> API docs' subtab
            where a detailed description of the Dashboard API is listed. Can
            be one of     'default or inherit', 'hide' or 'show'.
        hardware_replacements_subtab (HardwareReplacementsSubtabEnum): The
            'Help -> Replacement info' subtab where important information
            regarding device replacements is detailed. Can be one of    
            'default or inherit', 'hide' or 'show'.
        sm_forums (SmForumsEnum): The 'SM Forums' subtab which links to
            community-based support for Cisco Meraki Systems Manager. Only
            configurable for     organizations that contain Systems Manager
            networks. Can be one of 'default or inherit', 'hide' or 'show'.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "help_tab":'helpTab',
        "get_help_subtab":'getHelpSubtab',
        "community_subtab":'communitySubtab',
        "cases_subtab":'casesSubtab',
        "data_protection_requests_subtab":'dataProtectionRequestsSubtab',
        "get_help_subtab_knowledge_base_search":'getHelpSubtabKnowledgeBaseSearch',
        "universal_search_knowledge_base_search":'universalSearchKnowledgeBaseSearch',
        "cisco_meraki_product_documentation":'ciscoMerakiProductDocumentation',
        "support_contact_info":'supportContactInfo',
        "new_features_subtab":'newFeaturesSubtab',
        "firewall_info_subtab":'firewallInfoSubtab',
        "api_docs_subtab":'apiDocsSubtab',
        "hardware_replacements_subtab":'hardwareReplacementsSubtab',
        "sm_forums":'smForums'
    }

    def __init__(self,
                 help_tab=None,
                 get_help_subtab=None,
                 community_subtab=None,
                 cases_subtab=None,
                 data_protection_requests_subtab=None,
                 get_help_subtab_knowledge_base_search=None,
                 universal_search_knowledge_base_search=None,
                 cisco_meraki_product_documentation=None,
                 support_contact_info=None,
                 new_features_subtab=None,
                 firewall_info_subtab=None,
                 api_docs_subtab=None,
                 hardware_replacements_subtab=None,
                 sm_forums=None):
        """Constructor for the HelpSettings class"""

        # Initialize members of the class
        self.help_tab = help_tab
        self.get_help_subtab = get_help_subtab
        self.community_subtab = community_subtab
        self.cases_subtab = cases_subtab
        self.data_protection_requests_subtab = data_protection_requests_subtab
        self.get_help_subtab_knowledge_base_search = get_help_subtab_knowledge_base_search
        self.universal_search_knowledge_base_search = universal_search_knowledge_base_search
        self.cisco_meraki_product_documentation = cisco_meraki_product_documentation
        self.support_contact_info = support_contact_info
        self.new_features_subtab = new_features_subtab
        self.firewall_info_subtab = firewall_info_subtab
        self.api_docs_subtab = api_docs_subtab
        self.hardware_replacements_subtab = hardware_replacements_subtab
        self.sm_forums = sm_forums


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        help_tab = dictionary.get('helpTab')
        get_help_subtab = dictionary.get('getHelpSubtab')
        community_subtab = dictionary.get('communitySubtab')
        cases_subtab = dictionary.get('casesSubtab')
        data_protection_requests_subtab = dictionary.get('dataProtectionRequestsSubtab')
        get_help_subtab_knowledge_base_search = dictionary.get('getHelpSubtabKnowledgeBaseSearch')
        universal_search_knowledge_base_search = dictionary.get('universalSearchKnowledgeBaseSearch')
        cisco_meraki_product_documentation = dictionary.get('ciscoMerakiProductDocumentation')
        support_contact_info = dictionary.get('supportContactInfo')
        new_features_subtab = dictionary.get('newFeaturesSubtab')
        firewall_info_subtab = dictionary.get('firewallInfoSubtab')
        api_docs_subtab = dictionary.get('apiDocsSubtab')
        hardware_replacements_subtab = dictionary.get('hardwareReplacementsSubtab')
        sm_forums = dictionary.get('smForums')

        # Return an object of this model
        return cls(help_tab,
                   get_help_subtab,
                   community_subtab,
                   cases_subtab,
                   data_protection_requests_subtab,
                   get_help_subtab_knowledge_base_search,
                   universal_search_knowledge_base_search,
                   cisco_meraki_product_documentation,
                   support_contact_info,
                   new_features_subtab,
                   firewall_info_subtab,
                   api_docs_subtab,
                   hardware_replacements_subtab,
                   sm_forums)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class SsidNumberEnum(object):

    """Implementation of the 'ssidNumber' enum.

    TODO: type enum description here.

    Attributes:
        ENUM_0: TODO: type description here.
        ENUM_1: TODO: type description here.
        ENUM_2: TODO: type description here.
        ENUM_3: TODO: type description here.
        ENUM_4: TODO: type description here.
        ENUM_5: TODO: type description here.
        ENUM_6: TODO: type description here.
        ENUM_7: TODO: type description here.
        ENUM_8: TODO: type description here.
        ENUM_9: TODO: type description here.
        ENUM_10: TODO: type description here.
        ENUM_11: TODO: type description here.
        ENUM_12: TODO: type description here.
        ENUM_13: TODO: type description here.
        ENUM_14: TODO: type description here.

    """

    ENUM_0 = 0

    ENUM_1 = 1

    ENUM_2 = 2

    ENUM_3 = 3

    ENUM_4 = 4

    ENUM_5 = 5

    ENUM_6 = 6

    ENUM_7 = 7

    ENUM_8 = 8

    ENUM_9 = 9

    ENUM_10 = 10

    ENUM_11 = 11

    ENUM_12 = 12

    ENUM_13 = 13

    ENUM_14 = 14




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.hub
import test_meraki.models.subnet

class UpdateNetworkSiteToSiteVpn(object):

    """Implementation of the 'updateNetworkSiteToSiteVpn' model.

    TODO: type model description here.

    Attributes:
        mode (ModeEnum): The site-to-site VPN mode. Can be one of 'none',
            'spoke' or 'hub'
        hubs (list of Hub): The list of VPN hubs, in order of preference. In
            spoke mode, at least 1 hub is required.
        subnets (list of Subnet): The list of subnets and their VPN presence.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mode":'mode',
        "hubs":'hubs',
        "subnets":'subnets'
    }

    def __init__(self,
                 mode=None,
                 hubs=None,
                 subnets=None):
        """Constructor for the UpdateNetworkSiteToSiteVpn class"""

        # Initialize members of the class
        self.mode = mode
        self.hubs = hubs
        self.subnets = subnets


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mode = dictionary.get('mode')
        hubs = None
        if dictionary.get('hubs') != None:
            hubs = list()
            for structure in dictionary.get('hubs'):
                hubs.append(test_meraki.models.hub.Hub.from_dictionary(structure))
        subnets = None
        if dictionary.get('subnets') != None:
            subnets = list()
            for structure in dictionary.get('subnets'):
                subnets.append(test_meraki.models.subnet.Subnet.from_dictionary(structure))

        # Return an object of this model
        return cls(mode,
                   hubs,
                   subnets)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class BottomRightCorner(object):

    """Implementation of the 'BottomRightCorner' model.

    The longitude and latitude of the bottom right corner of your floor plan.

    Attributes:
        lat (float): Latitude
        lng (float): Longitude

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "lat":'lat',
        "lng":'lng'
    }

    def __init__(self,
                 lat=None,
                 lng=None):
        """Constructor for the BottomRightCorner class"""

        # Initialize members of the class
        self.lat = lat
        self.lng = lng


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        lat = dictionary.get('lat')
        lng = dictionary.get('lng')

        # Return an object of this model
        return cls(lat,
                   lng)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class FiveGhzSettings1(object):

    """Implementation of the 'FiveGhzSettings1' model.

    Settings related to 5Ghz band

    Attributes:
        max_power (int): Sets max power (dBm) of 5Ghz band. Can be integer
            between 8 and 30.
        min_power (int): Sets min power (dBm) of 5Ghz band. Can be integer
            between 8 and 30.
        min_bitrate (int): Sets min bitrate (Mbps) of 5Ghz band. Can be one of
            '6', '9', '12', '18', '24', '36', '48' or '54'.
        valid_auto_channels (list of int): Sets valid auto channels for 5Ghz
            band. Can be one of '36', '40', '44', '48', '52', '56', '60',
            '64', '100', '104', '108', '112', '116', '120', '124', '128',
            '132', '136', '140', '144', '149', '153', '157', '161' or '165'.
        channel_width (string): Sets channel width (MHz) for 5Ghz band. Can be
            one of 'auto', '20', '40' or '80'.
        rxsop (int): The RX-SOP level controls the sensitivity of the radio.
            It is strongly recommended to use RX-SOP only after     consulting
            a wireless expert. RX-SOP can be configured in the range of -65 to
            -95 (dBm). A value of null will     reset this to the default.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "max_power":'maxPower',
        "min_power":'minPower',
        "min_bitrate":'minBitrate',
        "valid_auto_channels":'validAutoChannels',
        "channel_width":'channelWidth',
        "rxsop":'rxsop'
    }

    def __init__(self,
                 max_power=None,
                 min_power=None,
                 min_bitrate=None,
                 valid_auto_channels=None,
                 channel_width=None,
                 rxsop=None):
        """Constructor for the FiveGhzSettings1 class"""

        # Initialize members of the class
        self.max_power = max_power
        self.min_power = min_power
        self.min_bitrate = min_bitrate
        self.valid_auto_channels = valid_auto_channels
        self.channel_width = channel_width
        self.rxsop = rxsop


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        max_power = dictionary.get('maxPower')
        min_power = dictionary.get('minPower')
        min_bitrate = dictionary.get('minBitrate')
        valid_auto_channels = dictionary.get('validAutoChannels')
        channel_width = dictionary.get('channelWidth')
        rxsop = dictionary.get('rxsop')

        # Return an object of this model
        return cls(max_power,
                   min_power,
                   min_bitrate,
                   valid_auto_channels,
                   channel_width,
                   rxsop)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateOrganizationNetwork(object):

    """Implementation of the 'createOrganizationNetwork' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of the new network
        mtype (string): The type of the new network. Valid types are wireless,
            appliance, switch, systemsManager, camera, or a space-separated
            list of those for a combined network.
        tags (string): A space-separated list of tags to be applied to the
            network
        time_zone (string): The timezone of the network. For a list of allowed
            timezones, please see the 'TZ' column in the table in <a
            target='_blank'
            href='https://en.wikipedia.org/wiki/List_of_tz_database_time_zones'
            >this article.</a>
        copy_from_network_id (string): The ID of the network to copy
            configuration from. Other provided parameters will override the
            copied configuration, except type which must match this network's
            type exactly.
        disable_my_meraki_com (bool): Disables the local device status pages
            (<a target='_blank' href='http://my.meraki.com/'>my.meraki.com,
            </a><a target='_blank' href='http://ap.meraki.com/'>ap.meraki.com,
            </a><a target='_blank'
            href='http://switch.meraki.com/'>switch.meraki.com, </a><a
            target='_blank'
            href='http://wired.meraki.com/'>wired.meraki.com</a>). Optional
            (defaults to false)
        disable_remote_status_page (bool): Disables access to the device
            status page (<a target='_blank'>http://[device's LAN IP])</a>.
            Optional. Can only be set if disableMyMerakiCom is set to false

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "mtype":'type',
        "tags":'tags',
        "time_zone":'timeZone',
        "copy_from_network_id":'copyFromNetworkId',
        "disable_my_meraki_com":'disableMyMerakiCom',
        "disable_remote_status_page":'disableRemoteStatusPage'
    }

    def __init__(self,
                 name=None,
                 mtype=None,
                 tags=None,
                 time_zone=None,
                 copy_from_network_id=None,
                 disable_my_meraki_com=None,
                 disable_remote_status_page=None):
        """Constructor for the CreateOrganizationNetwork class"""

        # Initialize members of the class
        self.name = name
        self.mtype = mtype
        self.tags = tags
        self.time_zone = time_zone
        self.copy_from_network_id = copy_from_network_id
        self.disable_my_meraki_com = disable_my_meraki_com
        self.disable_remote_status_page = disable_remote_status_page


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        mtype = dictionary.get('type')
        tags = dictionary.get('tags')
        time_zone = dictionary.get('timeZone')
        copy_from_network_id = dictionary.get('copyFromNetworkId')
        disable_my_meraki_com = dictionary.get('disableMyMerakiCom')
        disable_remote_status_page = dictionary.get('disableRemoteStatusPage')

        # Return an object of this model
        return cls(name,
                   mtype,
                   tags,
                   time_zone,
                   copy_from_network_id,
                   disable_my_meraki_com,
                   disable_remote_status_page)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetwork(object):

    """Implementation of the 'updateNetwork' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of the network
        time_zone (string): The timezone of the network. For a list of allowed
            timezones, please see the 'TZ' column in the table in <a
            target='_blank'
            href='https://en.wikipedia.org/wiki/List_of_tz_database_time_zones'
            >this article.</a>
        tags (string): A space-separated list of tags to be applied to the
            network
        disable_my_meraki_com (bool): Disables the local device status pages
            (<a target='_blank' href='http://my.meraki.com/'>my.meraki.com,
            </a><a target='_blank' href='http://ap.meraki.com/'>ap.meraki.com,
            </a><a target='_blank'
            href='http://switch.meraki.com/'>switch.meraki.com, </a><a
            target='_blank'
            href='http://wired.meraki.com/'>wired.meraki.com</a>). Optional
            (defaults to false)
        disable_remote_status_page (bool): Disables access to the device
            status page (<a target='_blank'>http://[device's LAN IP])</a>.
            Optional. Can only be set if disableMyMerakiCom is set to false
        enrollment_string (string): A unique identifier which can be used for
            device enrollment or easy access through the Meraki SM
            Registration page or the Self Service Portal. Please note that
            changing this field may cause existing bookmarks to break.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "time_zone":'timeZone',
        "tags":'tags',
        "disable_my_meraki_com":'disableMyMerakiCom',
        "disable_remote_status_page":'disableRemoteStatusPage',
        "enrollment_string":'enrollmentString'
    }

    def __init__(self,
                 name=None,
                 time_zone=None,
                 tags=None,
                 disable_my_meraki_com=None,
                 disable_remote_status_page=None,
                 enrollment_string=None):
        """Constructor for the UpdateNetwork class"""

        # Initialize members of the class
        self.name = name
        self.time_zone = time_zone
        self.tags = tags
        self.disable_my_meraki_com = disable_my_meraki_com
        self.disable_remote_status_page = disable_remote_status_page
        self.enrollment_string = enrollment_string


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        time_zone = dictionary.get('timeZone')
        tags = dictionary.get('tags')
        disable_my_meraki_com = dictionary.get('disableMyMerakiCom')
        disable_remote_status_page = dictionary.get('disableRemoteStatusPage')
        enrollment_string = dictionary.get('enrollmentString')

        # Return an object of this model
        return cls(name,
                   time_zone,
                   tags,
                   disable_my_meraki_com,
                   disable_remote_status_page,
                   enrollment_string)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class StateEnum(object):

    """Implementation of the 'state' enum.

    TODO: type enum description here.

    Attributes:
        ACTIVE: TODO: type description here.
        EXPIRED: TODO: type description here.
        EXPIRING: TODO: type description here.
        UNUSED: TODO: type description here.
        UNUSEDACTIVE: TODO: type description here.
        RECENTLYQUEUED: TODO: type description here.

    """

    ACTIVE = 'active'

    EXPIRED = 'expired'

    EXPIRING = 'expiring'

    UNUSED = 'unused'

    UNUSEDACTIVE = 'unusedActive'

    RECENTLYQUEUED = 'recentlyQueued'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.stp_bridge_priority

class UpdateNetworkSwitchSettingsStp(object):

    """Implementation of the 'updateNetworkSwitchSettingsStp' model.

    TODO: type model description here.

    Attributes:
        rstp_enabled (bool): The spanning tree protocol status in network
        stp_bridge_priority (list of StpBridgePriority): STP bridge priority
            for switches/stacks or switch profiles. An empty array will clear
            the STP bridge priority settings.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "rstp_enabled":'rstpEnabled',
        "stp_bridge_priority":'stpBridgePriority'
    }

    def __init__(self,
                 rstp_enabled=None,
                 stp_bridge_priority=None):
        """Constructor for the UpdateNetworkSwitchSettingsStp class"""

        # Initialize members of the class
        self.rstp_enabled = rstp_enabled
        self.stp_bridge_priority = stp_bridge_priority


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        rstp_enabled = dictionary.get('rstpEnabled')
        stp_bridge_priority = None
        if dictionary.get('stpBridgePriority') != None:
            stp_bridge_priority = list()
            for structure in dictionary.get('stpBridgePriority'):
                stp_bridge_priority.append(test_meraki.models.stp_bridge_priority.StpBridgePriority.from_dictionary(structure))

        # Return an object of this model
        return cls(rstp_enabled,
                   stp_bridge_priority)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class DashboardBrandingPoliciesController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_organization_branding_policies(self,
                                           organization_id):
        """Does a GET request to /organizations/{organizationId}/brandingPolicies.

        List the branding policies of an organization

        Args:
            organization_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/brandingPolicies'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_organization_branding_policy(self,
                                            organization_id,
                                            create_organization_branding_policy):
        """Does a POST request to /organizations/{organizationId}/brandingPolicies.

        Add a new branding policy to an organization

        Args:
            organization_id (string): TODO: type description here. Example: 
            create_organization_branding_policy
                (CreateOrganizationBrandingPolicy): TODO: type description
                here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/brandingPolicies'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_organization_branding_policy))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_organization_branding_policies_priorities(self,
                                                      organization_id):
        """Does a GET request to /organizations/{organizationId}/brandingPolicies/priorities.

        Return the branding policy IDs of an organization in priority order.
        IDs are ordered in ascending order of priority (IDs later in the array
        have higher priority).

        Args:
            organization_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/brandingPolicies/priorities'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_organization_branding_policies_priorities(self,
                                                         organization_id,
                                                         update_organization_branding_policies_priorities):
        """Does a PUT request to /organizations/{organizationId}/brandingPolicies/priorities.

        Update the priority ordering of an organization's branding policies.

        Args:
            organization_id (string): TODO: type description here. Example: 
            update_organization_branding_policies_priorities
                (UpdateOrganizationBrandingPoliciesPriorities): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/brandingPolicies/priorities'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_organization_branding_policies_priorities))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_organization_branding_policy(self,
                                         organization_id,
                                         branding_policy_id):
        """Does a GET request to /organizations/{organizationId}/brandingPolicies/{brandingPolicyId}.

        Return a branding policy

        Args:
            organization_id (string): TODO: type description here. Example: 
            branding_policy_id (string): TODO: type description here. Example:
                
        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/brandingPolicies/{brandingPolicyId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id,
            'brandingPolicyId': branding_policy_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_organization_branding_policy(self,
                                            organization_id,
                                            branding_policy_id,
                                            update_organization_branding_policy=None):
        """Does a PUT request to /organizations/{organizationId}/brandingPolicies/{brandingPolicyId}.

        Update a branding policy

        Args:
            organization_id (string): TODO: type description here. Example: 
            branding_policy_id (string): TODO: type description here. Example:
                            update_organization_branding_policy
                (UpdateOrganizationBrandingPolicy, optional): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/brandingPolicies/{brandingPolicyId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id,
            'brandingPolicyId': branding_policy_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_organization_branding_policy))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def delete_organization_branding_policy(self,
                                            organization_id,
                                            branding_policy_id):
        """Does a DELETE request to /organizations/{organizationId}/brandingPolicies/{brandingPolicyId}.

        Delete a branding policy

        Args:
            organization_id (string): TODO: type description here. Example: 
            branding_policy_id (string): TODO: type description here. Example:
                
        Returns:
            void: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/brandingPolicies/{brandingPolicyId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id,
            'brandingPolicyId': branding_policy_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.delete(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Type7Enum(object):

    """Implementation of the 'Type7' enum.

    The signature type for the custom pie chart item. Can be one of 'host',
    'port' or 'ipRange'.

    Attributes:
        HOST: TODO: type description here.
        PORT: TODO: type description here.
        IPRANGE: TODO: type description here.

    """

    HOST = 'host'

    PORT = 'port'

    IPRANGE = 'ipRange'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class BandwidthLimits(object):

    """Implementation of the 'BandwidthLimits' model.

    The bandwidth limits object, specifying upload and download speed for
    clients bound to the group policy. These are only enforced if 'settings'
    is set to 'custom'.

    Attributes:
        limit_up (int): The maximum upload limit (integer, in Kbps). null
            indicates no limit
        limit_down (int): The maximum download limit (integer, in Kbps). null
            indicates no limit

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "limit_up":'limitUp',
        "limit_down":'limitDown'
    }

    def __init__(self,
                 limit_up=None,
                 limit_down=None):
        """Constructor for the BandwidthLimits class"""

        # Initialize members of the class
        self.limit_up = limit_up
        self.limit_down = limit_down


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        limit_up = dictionary.get('limitUp')
        limit_down = dictionary.get('limitDown')

        # Return an object of this model
        return cls(limit_up,
                   limit_down)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class OrganizationsController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_organizations(self):
        """Does a GET request to /organizations.

        List the organizations that the user has privileges on

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_organization(self,
                            create_organization):
        """Does a POST request to /organizations.

        Create a new organization

        Args:
            create_organization (CreateOrganization): TODO: type description
                here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations'
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_organization))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_organization(self,
                         organization_id):
        """Does a GET request to /organizations/{organizationId}.

        Return an organization

        Args:
            organization_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_organization(self,
                            organization_id,
                            update_organization=None):
        """Does a PUT request to /organizations/{organizationId}.

        Update an organization

        Args:
            organization_id (string): TODO: type description here. Example: 
            update_organization (UpdateOrganization, optional): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_organization))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def delete_organization(self,
                            organization_id):
        """Does a DELETE request to /organizations/{organizationId}.

        Delete an organization

        Args:
            organization_id (string): TODO: type description here. Example: 

        Returns:
            void: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.delete(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

    def create_claim_organization(self,
                                  organization_id,
                                  claim_organization=None):
        """Does a POST request to /organizations/{organizationId}/claim.

        Claim a list of devices, licenses, and/or orders into an organization.
        When claiming by order, all devices and licenses in the order will be
        claimed; licenses will be added to the organization and devices will
        be placed in the organization's inventory.

        Args:
            organization_id (string): TODO: type description here. Example: 
            claim_organization (ClaimOrganization, optional): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/claim'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(claim_organization))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_clone_organization(self,
                                  organization_id,
                                  clone_organization):
        """Does a POST request to /organizations/{organizationId}/clone.

        Create a new organization by cloning the addressed organization

        Args:
            organization_id (string): TODO: type description here. Example: 
            clone_organization (CloneOrganization): TODO: type description
                here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/clone'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(clone_organization))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_organization_device_statuses(self,
                                         organization_id):
        """Does a GET request to /organizations/{organizationId}/deviceStatuses.

        List the status of every Meraki device in the organization

        Args:
            organization_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/deviceStatuses'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_organization_inventory(self,
                                   organization_id,
                                   include_license_info=None):
        """Does a GET request to /organizations/{organizationId}/inventory.

        Return the inventory for an organization

        Args:
            organization_id (string): TODO: type description here. Example: 
            include_license_info (bool, optional): When this parameter is
                true, each entity in the response will include the license
                expiration date of the device (if any). Only applies to
                organizations that support per-device licensing. Defaults to
                false.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/inventory'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'includeLicenseInfo': include_license_info
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_organization_license_state(self,
                                       organization_id):
        """Does a GET request to /organizations/{organizationId}/licenseState.

        Return the license state for an organization

        Args:
            organization_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/licenseState'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_organization_third_party_vpn_peers(self,
                                               organization_id):
        """Does a GET request to /organizations/{organizationId}/thirdPartyVPNPeers.

        Return the third party VPN peers for an organization

        Args:
            organization_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/thirdPartyVPNPeers'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_organization_third_party_vpn_peers(self,
                                                  organization_id,
                                                  update_organization_third_party_vpn_peers):
        """Does a PUT request to /organizations/{organizationId}/thirdPartyVPNPeers.

        Update the third party VPN peers for an organization

        Args:
            organization_id (string): TODO: type description here. Example: 
            update_organization_third_party_vpn_peers
                (UpdateOrganizationThirdPartyVPNPeers): TODO: type description
                here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/thirdPartyVPNPeers'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_organization_third_party_vpn_peers))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_organization_uplinks_loss_and_latency(self,
                                                  organization_id,
                                                  t_0=None,
                                                  t_1=None,
                                                  timespan=None,
                                                  uplink=None,
                                                  ip=None):
        """Does a GET request to /organizations/{organizationId}/uplinksLossAndLatency.

        Return the uplink loss and latency for every MX in the organization
        from at latest 2 minutes ago

        Args:
            organization_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 365 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 5 minutes after t0. The latest possible
                time that t1 can be is 2 minutes into the past.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 5 minutes. The default is 5 minutes.
            uplink (UplinkEnum, optional): Optional filter for a specific WAN
                uplink. Valid uplinks are wan1, wan2, cellular. Default will
                return all uplinks.
            ip (string, optional): Optional filter for a specific destination
                IP. Default will return all destination IPs.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/uplinksLossAndLatency'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'uplink': uplink,
            'ip': ip
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class AccessEnum(object):

    """Implementation of the 'Access' enum.

    A string indicating the rule for which IPs are allowed to use the
    specified service. Acceptable values are "blocked" (no remote IPs can
    access the service), "restricted" (only whitelisted IPs can access the
    service), and "unrestriced" (any remote IP can access the service). This
    field is required

    Attributes:
        BLOCKED: TODO: type description here.
        RESTRICTED: TODO: type description here.
        UNRESTRICTED: TODO: type description here.

    """

    BLOCKED = 'blocked'

    RESTRICTED = 'restricted'

    UNRESTRICTED = 'unrestricted'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateOrganizationActionBatch(object):

    """Implementation of the 'updateOrganizationActionBatch' model.

    TODO: type model description here.

    Attributes:
        confirmed (bool): A boolean representing whether or not the batch has
            been confirmed. This property cannot be unset once it is true.
        synchronous (bool): Set to true to force the batch to run synchronous.
            There can be at most 20 actions in synchronous batch.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "confirmed":'confirmed',
        "synchronous":'synchronous'
    }

    def __init__(self,
                 confirmed=None,
                 synchronous=None):
        """Constructor for the UpdateOrganizationActionBatch class"""

        # Initialize members of the class
        self.confirmed = confirmed
        self.synchronous = synchronous


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        confirmed = dictionary.get('confirmed')
        synchronous = dictionary.get('synchronous')

        # Return an object of this model
        return cls(confirmed,
                   synchronous)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class SmForumsEnum(object):

    """Implementation of the 'SmForums' enum.

    The 'SM Forums' subtab which links to community-based support for Cisco
    Meraki Systems Manager. Only configurable for
        organizations that contain Systems Manager networks. Can be one of
        'default or inherit', 'hide' or 'show'.

    Attributes:
        ENUM_DEFAULT OR INHERIT: TODO: type description here.
        HIDE: TODO: type description here.
        SHOW: TODO: type description here.

    """

    ENUM_DEFAULT_OR_INHERIT = 'default or inherit'

    HIDE = 'hide'

    SHOW = 'show'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Rule1(object):

    """Implementation of the 'Rule1' model.

    TODO: type model description here.

    Attributes:
        description (string): A description for your Bonjour forwarding rule.
            Optional.
        vlan_id (string): The ID of the service VLAN. Required.
        services (list of ServiceEnum): A list of Bonjour services. At least
            one service must be specified. Available services are 'All
            Services', 'AirPlay', 'AFP', 'BitTorrent', 'FTP', 'iChat',
            'iTunes', 'Printers', 'Samba', 'Scanners' and 'SSH'

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "vlan_id":'vlanId',
        "services":'services',
        "description":'description'
    }

    def __init__(self,
                 vlan_id=None,
                 services=None,
                 description=None):
        """Constructor for the Rule1 class"""

        # Initialize members of the class
        self.description = description
        self.vlan_id = vlan_id
        self.services = services


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        vlan_id = dictionary.get('vlanId')
        services = dictionary.get('services')
        description = dictionary.get('description')

        # Return an object of this model
        return cls(vlan_id,
                   services,
                   description)


